<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Добавить файлы</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Краткое представление</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Детальное представление</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Закрыть при добавлении</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Тип файла:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="121"/>
        <location filename="../qmmpfiledialog.cpp" line="130"/>
        <source>Qmmp File Dialog</source>
        <translation>Файловый диалог Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="129"/>
        <source>About Qmmp File Dialog</source>
        <translation>О файловом диалоге Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="131"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчики:
Владимир Кузнецов &lt;vovanec@gmail.com&gt;
Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="134"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Часть кода использована из библиотеки Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="272"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="288"/>
        <source>Directories</source>
        <translation>Директории</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 уже существует.
Заменить?</translation>
    </message>
</context>
</TS>
